Assemble
========



.. automodule:: repytah.assemble
   :members: breakup_overlaps_by_intersect, check_overlaps, hierarchical_structure
   :private-members: __compare_and_cut, __num_of_parts, __inds_to_rows, __merge_based_on_length, __merge_rows
